Unsigned64BitProvider

Struct Unsigned64BitProvider 

pub struct Unsigned64BitProvider { /* private fields */ }
A u64 data provider.

Notes

  • u64 are always stored in an little endian fashion to avoid any variances due to platform storage conventions.

Implementations

Source

impl Unsigned64BitProvider

pub fn new(length: usize) -> Self

Creates a new u64 data provider that returns length 64-bit unsigned integers (stored in a little endian representation).

Examples
use bitbelay_providers::numeric::Unsigned64BitProvider;
// The trait must also be in scope to access the `provide()` method.
use bitbelay_providers::Provider as _;

let mut provider = Unsigned64BitProvider::new(10);

let data = provider.provide(20);
assert_eq!(data.len(), 20);
// Note that each u64 is eight (8) bytes, so we can expect a length
// of `10 * 8 = 80`.
assert_eq!(data.first().unwrap().len(), 80);